@@ -414,6 +414,7 @@ fill_gradient_init (StylePrefState *state)
 
 	state->fill.gradient.brightness = brightness =
 		go_gtk_builder_get_widget (state->gui, "fill_brightness_scale");
+	gtk_range_set_value (GTK_RANGE (brightness), state->style->fill.gradient.brightness);
 	label = go_gtk_builder_get_widget (state->gui, "fill_brightness_label");
 	gtk_size_group_add_widget (state->fill.size_group, label);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), brightness);
@@ -495,7 +496,8 @@ cb_image_select (GtkWidget *cc, StylePrefState *state)
 
 	w = go_image_sel_new (state->doc, NULL, &style->fill.image.image);
 	gtk_window_set_transient_for (GTK_WINDOW (w), GTK_WINDOW (gtk_widget_get_toplevel (cc)));
-	gtk_dialog_run (GTK_DIALOG (w));
+	/* we need to call gtk_run_dialog until it returns a non NULL response */
+	while (! gtk_dialog_run (GTK_DIALOG (w)));
 
 	go_style_set_image_preview (style->fill.image.image, state);
 	set_style (state);
@@ -595,6 +597,9 @@ cb_fill_type_changed (GtkWidget *menu, StylePrefState *state)
 
 	index = CLAMP (gtk_combo_box_get_active (GTK_COMBO_BOX (menu)), 0, (int) G_N_ELEMENTS (fill_infos) - 1);
 
+	if (state->style->fill.type == GO_STYLE_FILL_GRADIENT)
+	/* we need to set brightness to 0 because of unicolor gradients recognition */
+		gtk_range_set_value (GTK_RANGE (state->fill.gradient.brightness), 0.);
 	state->style->fill.type = fill_infos[index].type;
 	state->style->fill.auto_type = FALSE;
 	set_style (state);
@@ -962,8 +967,15 @@ go_style_populate_editor (GOStyle *style,
 	state->object_with_style = object_with_style;
 	state->enable_edit = FALSE;
 
-	state->doc = (GO_IS_STYLED_OBJECT (object_with_style))?
-		go_styled_object_get_document (GO_STYLED_OBJECT (object_with_style)): NULL;
+	if (GO_IS_STYLED_OBJECT (object_with_style))
+		state->doc = go_styled_object_get_document (GO_STYLED_OBJECT (object_with_style));
+	else {
+		GObjectClass *klass = G_OBJECT_GET_CLASS (object_with_style);
+		if (g_object_class_find_property (klass, "document") != NULL)
+			g_object_get (object_with_style, "document", &(state->doc), NULL);
+	}
+	if (state->doc && !GO_IS_DOC (state->doc))
+		state->doc = NULL;
 
 	if ((enable & (GO_STYLE_OUTLINE | GO_STYLE_LINE | GO_STYLE_FILL)) != 0) {
 		gui = go_gtk_builder_new ("go-style-prefs.ui", GETTEXT_PACKAGE, cc);
@@ -1052,10 +1064,6 @@ go_style_assign (GOStyle *dst, GOStyle const *src)
 
 	g_return_if_fail (GO_IS_STYLE (src));
 	g_return_if_fail (GO_IS_STYLE (dst));
-
-	if (GO_STYLE_FILL_IMAGE == src->fill.type &&
-	    src->fill.image.image != NULL)
-		g_object_ref (src->fill.image.image);
 	if (GO_STYLE_FILL_IMAGE == dst->fill.type) {
 		if (dst->fill.image.image != NULL)
 			g_object_unref (dst->fill.image.image);
@@ -2000,15 +2008,17 @@ go_style_set_font (GOStyle *style, GOFont const *font)
 void
 go_style_set_fill_brightness (GOStyle *style, float brightness)
 {
+	double limit;
 	g_return_if_fail (GO_IS_STYLE (style));
 	g_return_if_fail (style->fill.type == GO_STYLE_FILL_GRADIENT);
 
 	brightness = CLAMP (brightness, 0, 100.0);
+	limit = (GO_COLOR_UINT_R (style->fill.pattern.back) + GO_COLOR_UINT_G (style->fill.pattern.back) + GO_COLOR_UINT_B (style->fill.pattern.back)) / 7.65;
 
 	style->fill.gradient.brightness = brightness;
-	style->fill.pattern.fore = (brightness < 50.)
-		? GO_COLOR_INTERPOLATE(style->fill.pattern.back, GO_COLOR_WHITE, 1. - brightness / 50.)
-		: GO_COLOR_INTERPOLATE(style->fill.pattern.back, GO_COLOR_BLACK, brightness / 50. - 1.);
+	style->fill.pattern.fore = (brightness <= limit && limit > 0.)
+		? GO_COLOR_INTERPOLATE(style->fill.pattern.back, GO_COLOR_BLACK, 1. - brightness / limit)
+		: GO_COLOR_INTERPOLATE(style->fill.pattern.back, GO_COLOR_WHITE, (brightness - limit) / (100. - limit));
 }
 
 /**
@@ -2122,6 +2132,8 @@ go_style_create_cairo_pattern (GOStyle const *style, cairo_t *cr)
 					cairo_pattern_set_matrix (cr_pattern, &cr_matrix);
 					break;
 				case GO_IMAGE_WALLPAPER:
+					cairo_matrix_init_translate (&cr_matrix, -x[0], -y[0]);
+					cairo_pattern_set_matrix (cr_pattern, &cr_matrix);
 					break;
 			}
 			return cr_pattern;
@@ -2132,3 +2144,58 @@ go_style_create_cairo_pattern (GOStyle const *style, cairo_t *cr)
 
 	return NULL;
 }
+
+gboolean
+go_style_set_cairo_line (GOStyle const *style, cairo_t *cr)
+{
+	double width;
+	GOLineDashSequence *line_dash;
+
+	g_return_val_if_fail (GO_IS_STYLE (style) && cr != NULL, FALSE);
+	if (style->line.dash_type == GO_LINE_NONE)
+		return FALSE;
+	width = (style->line.width)? style->line.width: 1.;
+	cairo_set_line_width (cr, width);
+	cairo_set_line_cap (cr, style->line.cap);
+	cairo_set_line_join (cr, style->line.join);
+	cairo_set_miter_limit (cr, style->line.miter_limit);
+	line_dash = go_line_dash_get_sequence (style->line.dash_type, width);
+	if (style->line.cap == CAIRO_LINE_CAP_BUTT && style->line.dash_type != GO_LINE_SOLID) {
+		unsigned i;
+		for (i = 0; i < line_dash->n_dash; i++)
+			if (line_dash->dash[i] == 0.)
+				line_dash->dash[i] = width;
+	}
+	if (line_dash != NULL)
+		cairo_set_dash (cr,
+				line_dash->dash,
+				line_dash->n_dash,
+				line_dash->offset);
+	else
+		cairo_set_dash (cr, NULL, 0, 0);
+	switch (style->line.pattern) {
+	case GO_PATTERN_SOLID:
+		cairo_set_source_rgba (cr, GO_COLOR_TO_CAIRO (style->line.color));
+		break;
+	case GO_PATTERN_FOREGROUND_SOLID:
+		cairo_set_source_rgba (cr, GO_COLOR_TO_CAIRO (style->line.fore));
+		break;
+	default: {
+		GOPattern pat;
+		double scalex = 1., scaley = 1.;
+		cairo_pattern_t *cp;
+		cairo_matrix_t mat;
+		pat.fore = style->line.fore;
+		pat.back = style->line.color;
+		pat.pattern = style->line.pattern;
+		cp = go_pattern_create_cairo_pattern (&pat, cr);
+		cairo_user_to_device_distance (cr, &scalex, &scaley);
+		cairo_matrix_init_scale (&mat, scalex, scaley);
+		cairo_pattern_set_matrix (cp, &mat);
+		cairo_set_source (cr, cp);
+		cairo_pattern_destroy (cp);
+		break;
+	}
+	}
+	return TRUE;
+}
